#
# spec file for package python-cpplint
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-cpplint
Version:        1.6.1
Release:        3.1
Summary:        An automated checker to make sure a C++ file follows Google's C++ style guide
License:        BSD-3-Clause
URL:            https://github.com/cpplint/cpplint
Source:         https://files.pythonhosted.org/packages/source/c/cpplint/cpplint-%{version}.tar.gz
# PATCH-FIX-UPSTREAM drop-sre-compile.patch gh#cpplint/cpplint#214
Patch0:         drop-sre-compile.patch
# PATCH-FIX-UPSTREAM python312.patch gh#cpplint/cpplint#243
Patch1:         python312.patch
# PATCH-FIX-UPSTREAM deprecated-unittest-aliases.patch gh#cpplint/cpplint#182
Patch2:         deprecated-unittest-aliases.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testfixtures}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This project continues the work of cpplint, a C++ style checker
following Google's C++ style guide. It provides cpplint as a PyPI
package and adds a few features and fixes. It is maintained as a
fork of google/styleguide (https://github.com/google/styleguide)
in hopes that it can be merged in the future.

%prep
%autosetup -p1 -n cpplint-%{version}
sed -i -e '/^#!\//, 1d' cpplint.py
sed -i 's/pytest-runner==5.2//' setup.py
sed -i 's/pytest-cov//' test-requirements
sed -i 's/--cov-fail-under=75 --cov=cpplint//' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/cpplint
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative cpplint

%postun
%python_uninstall_alternative cpplint

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/cpplint
%{python_sitelib}/cpplint.py
%pycache_only %{python_sitelib}/__pycache__/cpplint.*.pyc
%{python_sitelib}/cpplint-%{version}.dist-info

%changelog
* Mon Jun 16 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyroject macros.
* Tue Feb 20 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add upstream patches to support python 3.12
  - deprecated-unittest-aliases.patch, gh#cpplint/cpplint#182
  - python312.patch, gh#cpplint/cpplint#243
* Mon Apr 10 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add drop-sre-compile.patch upstream patch to fix issues with
  deprecated usage of sre_compile gh#cpplint/cpplint#214
- Update to 1.6.1
  * Fix #195 Fix post increment/decrement operator causing a false positive.
  * Fix #202 .hh files should not be considered sytem headers
  * Fix #207 Python2 incompatibility for loading CPPLINT.cfg file
  * Fix #184 NOLINT(clang-analyzer) comments should not cause warnings
- 1.6.0 (2022-02-19)
  * Fix #188: "Include the directory when naming header files" also
    for header files with other names like "*.hpp"
- 1.5.5 (2021-05-20)
  * Fix #172: Added 'size_t' to typecasts detected by CheckCStyleCast
  * Fixed wrong CLI help text: Each filter needs + or -
  * Fix #164: add elif as an exception for CheckSpacingForFunctionCall()
  * Fix google#346: --root option not working on windows due to
    slashes in path
* Mon Aug 31 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.5.4:
  * Fix google#166, Allow space before C++11 attributes
  * Fix #156: sed/gsed output parameter rejected
  * Fix #156: sed/gsed output without other stdout information
  * improvements to regression tests
* Wed Jul  1 2020 Steve Kowalik <steven.kowalik@suse.com>
- Add missing BuildRequires on textfixtures.
* Thu Jun 25 2020 Steve Kowalik <steven.kowalik@suse.com>
-  Update to 1.5.2:
  * Fix #83, output formats "sed" and "gsed" to auto-fix some issues
  * Fix #92, new category "build/namespaces_headers" for unnamed namespaces in header file
  * Sort list of files before processing
  * Fix #144 Falso positive for indent when using QT macros "signals" and "slots"
  * Fix #76 Parsing of class decorators that also use digits
  * Fix #139 Add message "Relative paths like . and .. are not allowed"
  * Revert #43 behavior change for include order from 1.5.0, and hide it behind command-line-flag --includeorder=standardcfirst. It turns out there is no easy objective way to tell c system headers from certain c++ library headers, and Google cpplint intentionally classifies some C++ header includes as C system header for simplicity.
  * Libraries considered as C system headers using --includeorder=standardcfirst now also includes linux-specifc headers (glibc-devel, glibc-kernheaders, linux-libc-dev).
  * Fix #43 false positives in header include order by checking includes against a list of c headers. Since this interprets certain include lines different than before, output about header include order changes.
  * Fix #135: allow 'if constexpr' in readability/braces.
  * Fix runtime warning: Close files after reading contents
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr  1 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.4.5
  * Add support for c++17 tuple destructuring
  * Travis CI: Add Python 3.8 to the testing
  * Fix linting unnecessary elif after break
* Mon Feb 25 2019 John Vandenberg <jayvdb@gmail.com>
- Remove bcond test
- Remove unnecessary build dependency on python devel
- Add %%license
- Update to v1.4.4
  * fix unit/cli tests for source release
  * reduce diff to upstream by intentionally using deprecated functions
    where upstream uses them
  * add --version
- from 1.4.3
  * Revert "Fix the build/endif_comment check", same as reverted in upstream
- from 1.4.2
  * Cleanup release, fixes further issues with tests and source distribution
- from 1.4.1
  * Cleanup release, only adds test support files to source dist
- from 1.4.0
  * Incorporate cpplint updates from google (e5d807c6a0d, 2018-05-03)
  * Fix the build/endif_comment check
  * Teach the explicit constructor check about constexpr
  * Changed vs7 output format
  * Remove presubmit check for DISALLOW_* macros
  * add --quiet flag as in upstream
  * support --root argument to run in different folder
  * Fix 16bit Unicode issue
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version for v1.3.0
